SQLAlchemy Core — SQLAlchemy 2.0 Documentation

Release: 2.0.1 | Release Date: February 1, 2023

# SQLAlchemy 2.0 Documentation

# SQLAlchemy Core

The breadth of SQLAlchemy’s SQL rendering engine, DBAPI integration, transaction integration, and schema description services are documented here. In contrast to the ORM’s domain-centric mode of usage, the SQL Expression Language provides a schema-centric usage paradigm.

- SQL Statements and Expressions API
  - Column Elements and Expressions
  - Operator Reference
  - SELECT and Related Constructs
  - Insert, Updates, Deletes
  - SQL and Generic Functions
  - Custom SQL Constructs and Compilation Extension
  - Expression Serializer Extension
  - SQL Expression Language Foundational Constructs
  - Visitor and Traversal Utilities
- Schema Definition Language
  - Describing Databases with MetaData
  - Reflecting Database Objects
  - Column INSERT/UPDATE Defaults
  - Defining Constraints and Indexes
  - Customizing DDL
- SQL Datatype Objects
  - The Type Hierarchy
  - Custom Types
  - Base Type API
- Engine and Connection Use
  - Engine Configuration
  - Working with Engines and Connections
  - Connection Pooling
  - Core Events
- Core API Basics
  - Events
  - Runtime Inspection API
  - Core Exceptions
  - Core Internals